@@ -30,7 +30,7 @@
 
 /* avr/iom164.h - definitions for ATmega164 */
 
-/* $Id: iom164.h,v 1.3.2.5 2009/02/11 18:05:26 arcanum Exp $ */
+/* $Id: iom164.h,v 1.3.2.6 2009/04/25 21:01:29 arcanum Exp $ */
 
 #ifndef _AVR_IOM164_H_
 #define _AVR_IOM164_H_ 1
@@ -85,4 +85,10 @@
 #define __BOOT_LOCK_BITS_1_EXIST 
 
 
+/* Signature (ATmega164P) */
+#define SIGNATURE_0 0x1E
+#define SIGNATURE_1 0x94
+#define SIGNATURE_2 0x0A 
+
+
 #endif /* _AVR_IOM164_H_ */
